========================
Cassiny-CLI
========================
.. image:: https://pyup.io/repos/github/cassinyio/cassiny-cli/shield.svg
     :target: https://pyup.io/repos/github/cassinyio/cassiny-cli/
     :alt: Updates

.. image:: https://pyup.io/repos/github/cassinyio/cassiny-cli/python-3-shield.svg
     :target: https://pyup.io/repos/github/cassinyio/cassiny-cli/
     :alt: Python 3

.. image:: https://badge.fury.io/py/cassiny.svg
   :target: https://badge.fury.io/py/cassiny
   :alt: PyPI version

.. image:: https://img.shields.io/pypi/pyversions/cassiny.svg
   :target: https://pypi.org/project/cassiny/
   :alt: Python Versions

.. image:: https://travis-ci.org/cassinyio/cassiny-cli.svg?branch=master
    :target: https://travis-ci.org/cassinyio/cassiny-cli
    :alt: Build Status

.. image:: https://codecov.io/gh/cassinyio/cassiny-cli/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/cassinyio/cassiny-cli

A CLI to interact with Cassiny's server.

Installation
============

.. code-block:: sh

   pip install cassiny

Documentation
=============

http://docs.cassiny.io
